summaryrefslogtreecommitdiffstats
path: root/libk3b/tools/k3bradioaction.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commitdf8e67b86696f691708af8592d86282b09bab011 (patch)
treeca90d734c9011d457a42f0a7004a9507b2c2c1bd /libk3b/tools/k3bradioaction.h
parent33881ea4441221b1ca0789a72c4c7249d923a0df (diff)
downloadk3b-df8e67b86696f691708af8592d86282b09bab011.tar.gz
k3b-df8e67b86696f691708af8592d86282b09bab011.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k3b@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk3b/tools/k3bradioaction.h')
-rw-r--r--libk3b/tools/k3bradioaction.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/libk3b/tools/k3bradioaction.h b/libk3b/tools/k3bradioaction.h
index d65b3f5..262e153 100644
--- a/libk3b/tools/k3bradioaction.h
+++ b/libk3b/tools/k3bradioaction.h
@@ -39,72 +39,72 @@ class LIBK3B_EXPORT K3bRadioAction : public KToggleAction
*
* @param text The text that will be displayed.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
- K3bRadioAction( const TQString& text, const KShortcut& cut = KShortcut(), TQObject* tqparent = 0, const char* name = 0 );
+ K3bRadioAction( const TQString& text, const KShortcut& cut = KShortcut(), TQObject* parent = 0, const char* name = 0 );
/**
* @param text The text that will be displayed.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param receiver The SLOT's tqparent.
* @param slot The TQT_SLOT to invoke to execute this action.
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
K3bRadioAction( const TQString& text, const KShortcut& cut,
- const TQObject* receiver, const char* slot, TQObject* tqparent, const char* name = 0 );
+ const TQObject* receiver, const char* slot, TQObject* parent, const char* name = 0 );
/**
* @param text The text that will be displayed.
* @param pix The icons that go with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
K3bRadioAction( const TQString& text, const TQIconSet& pix, const KShortcut& cut = KShortcut(),
- TQObject* tqparent = 0, const char* name = 0 );
+ TQObject* parent = 0, const char* name = 0 );
/**
* @param text The text that will be displayed.
* @param pix The dynamically loaded icon that goes with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
K3bRadioAction( const TQString& text, const TQString& pix, const KShortcut& cut = KShortcut(),
- TQObject* tqparent = 0, const char* name = 0 );
+ TQObject* parent = 0, const char* name = 0 );
/**
* @param text The text that will be displayed.
* @param pix The icons that go with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param receiver The SLOT's tqparent.
* @param slot The TQT_SLOT to invoke to execute this action.
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
K3bRadioAction( const TQString& text, const TQIconSet& pix, const KShortcut& cut,
- const TQObject* receiver, const char* slot, TQObject* tqparent, const char* name = 0 );
+ const TQObject* receiver, const char* slot, TQObject* parent, const char* name = 0 );
/**
* @param text The text that will be displayed.
* @param pix The dynamically loaded icon that goes with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param receiver The SLOT's tqparent.
* @param slot The TQT_SLOT to invoke to execute this action.
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
K3bRadioAction( const TQString& text, const TQString& pix, const KShortcut& cut,
const TQObject* receiver, const char* slot,
- TQObject* tqparent, const char* name = 0 );
+ TQObject* parent, const char* name = 0 );
/**
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
- K3bRadioAction( TQObject* tqparent = 0, const char* name = 0 );
+ K3bRadioAction( TQObject* parent = 0, const char* name = 0 );
/**
* @param b if true the action will always emit the activated signal
@@ -39,72 +39,72 @@ class LIBK3B_EXPORT K3bRadioAction : public KToggleAction
* @param text The text that will be displayed.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -39,72 +39,72 @@ class LIBK3B_EXPORT K3bRadioAction : public KToggleAction
* @param text The text that will be displayed.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param receiver The SLOT's tqparent.
+ * @param receiver The SLOT's parent.
* @param slot The TQT_SLOT to invoke to execute this action.
@@ -39,72 +39,72 @@ class LIBK3B_EXPORT K3bRadioAction : public KToggleAction
* @param slot The TQT_SLOT to invoke to execute this action.
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -39,72 +39,72 @@ class LIBK3B_EXPORT K3bRadioAction : public KToggleAction
* @param pix The icons that go with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -39,72 +39,72 @@ class LIBK3B_EXPORT K3bRadioAction : public KToggleAction
* @param pix The dynamically loaded icon that goes with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -39,72 +39,72 @@ class LIBK3B_EXPORT K3bRadioAction : public KToggleAction
* @param pix The icons that go with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param receiver The SLOT's tqparent.
+ * @param receiver The SLOT's parent.
* @param slot The TQT_SLOT to invoke to execute this action.
@@ -39,72 +39,72 @@ class LIBK3B_EXPORT K3bRadioAction : public KToggleAction
* @param slot The TQT_SLOT to invoke to execute this action.
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -39,72 +39,72 @@ class LIBK3B_EXPORT K3bRadioAction : public KToggleAction
* @param pix The dynamically loaded icon that goes with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param receiver The SLOT's tqparent.
+ * @param receiver The SLOT's parent.
* @param slot The TQT_SLOT to invoke to execute this action.
@@ -39,72 +39,72 @@ class LIBK3B_EXPORT K3bRadioAction : public KToggleAction
* @param slot The TQT_SLOT to invoke to execute this action.
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -39,72 +39,72 @@ class LIBK3B_EXPORT K3bRadioAction : public KToggleAction
/**
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/